Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/dataknobs_xization/annotations.py | 493 | 338 | 122 | 31%
src/dataknobs_xization/authorities.py | 177 | 112 | 127 | 37%
src/dataknobs_xization/lexicon.py | 213 | 148 | 69 | 31%
src/dataknobs_xization/markdown/enrichment.py | 61 | 21 | 0 | 66%
src/dataknobs_xization/markdown/filters.py | 86 | 64 | 2 | 26%
src/dataknobs_xization/markdown/md_chunker.py | 157 | 112 | 0 | 29%
src/dataknobs_xization/markdown/md_parser.py | 264 | 221 | 0 | 16%
src/dataknobs_xization/markdown/md_streaming.py | 63 | 46 | 0 | 27%
src/dataknobs_xization/masking_tokenizer.py | 293 | 194 | 54 | 34%
src/dataknobs_xization/normalize.py | 156 | 128 | 0 | 18%
Total | 1963 | 1384 | 374 | 29%

No items found using the specified filter.